@@ -1,7 +1,6 @@
 # coding: utf-8
 import json
 import os
-import sys
 import time
 from argparse import ArgumentParser, RawTextHelpFormatter
 
@@ -9,8 +8,8 @@ import psutil
 from BaseColor.base_colors import hgreen, hblue, red, hred
 from redis import AuthenticationError
 
-from NetRecorder.gear_for_nr import tell_the_datetime, convert_bytes, find_local_redis_pass, start_up_check, \
-    _get_host_name, _get_current_ip3, get_redis_cli, default_redis_params, get_redis_list_last
+from NetRecorder.gear_for_nr import tell_the_datetime, convert_bytes, start_up_check, \
+    _get_host_name, get_redis_cli, default_redis_params, get_redis_list_last, _get_current_ip4
 
 
 def get_refresh_time(refresh_rate):
@@ -99,7 +98,7 @@ def start(ip_keys, print_out=True, unit="auto", refresh_rate="s", push_redis=Fal
                     exit(1)
                 if push_redis:
                     hostname = _get_host_name()
-                    ip_info = _get_current_ip3(ip_info)
+                    ip_info = _get_current_ip4(ip_info)
                     location_info = json.loads(get_redis_list_last("NetRecLocation")) or {}
                     insert_obj = json.dumps({i_key: {"in": ne_in.get(i_key),
                                                      "out": ne_out.get(i_key),
@@ -161,68 +160,7 @@ def record_starter():
                              f'默认input\n')
     args = parser.parse_args()
     if args.place_script:
-        return start_up_check()
-    n_devices = [x.strip() for x in args.net_devices.split(",")]
-    unit = args.unit
-    refresh_rate = args.refresh_rate.lower()
-    push_to_redis = args.push_redis
-    key_params_mode = args.key_params
-    push_to_redis = True if push_to_redis == 'y' or push_to_redis is None else False
-    key_params = {}
-    if push_to_redis:
-        start_up_check()
-        if key_params_mode.startswith("now"):
-            key_params = key_params_mode.split(">>>>")[-1]
-            try:
-                key_params = json.loads(key_params)
-            except Exception as E:
-                print(f"can not load key params: \n{key_params}\n{E}")
-                key_params = {}
-        elif key_params_mode.startswith("input"):
-            key_params = {
-                "host": input("target redis host(127.0.0.1): ") or "127.0.0.1",
-                "port": int(input("port(6379): ") or 6379),
-                "db": int(input("db(0): ") or 0),
-                "password": input("password(123456): ") or "123456",
-                "insert_key": input("insert_key(NetRecs): ") or "NetRecs",
-            }
-        elif key_params_mode.startswith("local"):
-            try:
-                key_params = json.loads(get_redis_list_last("NetRec_key_params"))
-                if not key_params:
-                    print("no setting found in local redis, please check and restart")
-                    exit(1)
-            except AuthenticationError:
-                print("password not correct! ")
-                exit(1)
-            except IndexError:
-                print("no values in local redis key: NetRec_key_params")
-                exit(1)
-    # sys.stdout = Logger(os.path.join(os.getcwd(), f"netrecord_{tell_the_datetime(compact_mode=True)}.log"))
-    start(n_devices, print_out=True, unit=unit, refresh_rate=refresh_rate, push_redis=push_to_redis, target_redis_params=key_params)
-
-
-def record_starter_server():
-    dp = '    这是一个查看或者返回服务器流量信息的工具，以服务的方式启动，默认使用推 redis 的方式，单位为 bytes/m\n' \
-         '    https://github.com/ga1008/net_tracfic_recorder'
-    da = ""
-    parser = ArgumentParser(description=dp, formatter_class=RawTextHelpFormatter, add_help=True)
-    parser.add_argument("-n", "--net_devices", type=str, dest="net_devices", default='eth0,enp2s0',
-                        help=f'{da}指定网络设备，默认 eth0。多个值使用英文逗号 "," 隔开\n')
-    parser.add_argument("-u", "--unit", type=str, dest="unit", default='bytes',
-                        help=f'{da}指定流量单位，auto/bytes/kb/mb/gb，默认bytes\n')
-    parser.add_argument("-rf", "--refresh_rate", type=str, dest="refresh_rate", default='m',
-                        help=f'{da}统计频率，h/m/s (时/分/秒)，默认m\n')
-    parser.add_argument("-pr", "--push_redis", type=str, dest="push_redis", default='y', nargs='?',
-                        help=f'{da}y/n。将结果推入指定的redis，默认n。如果设置了此参数，则接下来需要提供目标redis的信息\n')
-    parser.add_argument("-kp", "--key_params", type=str, dest="key_params", default='local',
-                        help=f'{da}关键参数提供方式，input/local/now，\n'
-                             f'input是随后输入，\n'
-                             f'local是在本地redis的"NetRec_key_params"内寻找，\n'
-                             'now是后面直接跟上>>>>参数字典，例如：now>>>>{"host": "127.0.0.1", "port": ..., "db": ...}，'
-                             'now方式仅限测试\n'
-                             f'默认input\n')
-    args = parser.parse_args()
+        return start_up_check(dont_ask=True)
     n_devices = [x.strip() for x in args.net_devices.split(",")]
     unit = args.unit
     refresh_rate = args.refresh_rate.lower()
@@ -264,6 +202,7 @@ def record_starter_server():
 
 
 if __name__ == '__main__':
-    s_keys = sys.argv[1:] or ["eth0", "enp2s0"]
-    res = start(s_keys, print_out=False, unit="auto")
-    print(res)
+    # s_keys = sys.argv[1:] or ["eth0", "enp2s0"]
+    # res = start(s_keys, print_out=False, unit="auto")
+    # print(res)
+    record_starter()
\ No newline at end of file
