@@ -105,7 +105,8 @@ def start_up_check(dont_ask=False):
     local_path = os.path.split(os.path.abspath(__file__))[0]
     gen_server_script(local_path)
     os.popen(
-        f'sudo cp {os.path.join(local_path, "nettrarec")} /etc/init.d/ && sudo chmod +x /etc/init.d/nettrarec').read()
+        f'sudo cp {os.path.join(local_path, "nettrarec")} /etc/rc.d/init.d/ && sudo chmod +x /etc/rc.d/init.d/nettrarec'
+    ).read()
     print("It looks like the first run")
     if dont_ask:
         do = 'y'
@@ -114,7 +115,7 @@ def start_up_check(dont_ask=False):
     if do == 'y':
         print("adding nettrarec to system service")
         os.popen(
-            'chkconfig --add nettrarec && chkconfig nettrarec on && systemctl start nettrarec'
+            'chkconfig --add /etc/rc.d/init.d/nettrarec && chkconfig /etc/rc.d/init.d/nettrarec on && systemctl start /etc/rc.d/init.d/nettrarec'
         ).read()
         print(green("\nnettrarec has add to system service and set to start automatically at system boot\n"))
 
@@ -177,5 +178,17 @@ def _get_current_ip3(last_ip_info):
     return ip_info
 
 
+def _get_current_ip4(last_ip_info):
+    ip_info = last_ip_info
+    try:
+        res = requests.get("http://meesee.top/ip").text
+        ip_info['ip'] = re.findall(r"your ip: +([\d.]+)\n", res)[0]
+        ip_info['city'] = ' '
+        ip_info['country'] = ' '
+    except Exception as E:
+        print(f"Error in getting ip info: \n{E}")
+    return ip_info
+
+
 if __name__ == '__main__':
     print(find_local_redis_pass())
